==> spip_4.0.4.orig.tar.xz: plugins-dist/mots/lang/adminmots_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/adminmots?lang_cible=eo
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_associer' => 'Asocii',
	'bouton_dissocier' => 'Malasocii',
	'bouton_fusionner' => 'Kunfandi',

	// E
	'erreur_admin_mot_action_inconnue' => 'Kion vi volas fari ?',
	'erreur_mot_cle_deja' => 'Ne eblas : estas la vorto, sur kiu vi jam estas.',
	'erreur_selection_id' => 'Elektu ŝlosilvorton aŭ indiki ĝian identigilon en la tekstokampo',

	// I
	'icone_administrer_mot' => 'Detala admin.',

	// L
	'label_associer_objets_mot' => '<b>Asocii</b> tiun vorton al la objektoj, kiuj jam havas tiun vorton',
	'label_confirm_fusion' => 'Tiu operacio ne estas nuligebla.<br />
<strong>La aktuala ŝlosilvorto #@id_mot@ estos forigita</strong> kaj la jenaj ligiloj estos alkroĉitaj al la vorto #@id_mot_new@ : ',
	'label_confirm_fusion_check' => 'Marku por konfirmi la kunfando de la vorto #@id_mot@ kun la vorto #@id_mot_new@',
	'label_dissocier_objets_mot' => '<b>Malasocii</b> tiun vorton el la objektoj, kiuj ankaŭ havas tiun vorton',
	'label_fusionner_mot' => '<b>Kunfandi</b> kun la ŝlosilvorto',
	'label_mot_1_enfant' => 'Ido :',
	'label_mot_nb_enfants' => 'Idoj :',
	'label_mot_parent' => 'Patro :',

	// P
	'placeholder_id_mot' => 'aŭ #ID_MOT',
	'placeholder_select' => 'Elekti...',

	// R
	'result_associer_nb' => 'estis asociitaj al tiu ŝlosilvorto',
	'result_associer_ras' => 'Nenio farenda : ĉiuj objektoj jam havas tiun ŝlosilvorton',
	'result_cancel_ok' => 'La lasta operacio estis nuligita.',
	'result_dissocier_nb' => 'estis malasociitaj el tiu ŝlosilvorto',
	'result_dissocier_ras' => 'Nenio farenda : neniu koncernata objekto estas asociita al tiu ŝlosilvorto',
	'result_fusionner_ok' => 'Vi povas nun forigi tiun vorton : ĉiuj ligiloj translokiĝis al la alia @mot@.',

	// T
	'titre_formulaire_administrer_mot' => 'Administri la vorton'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/mots/lang/adminmots_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/adminmots?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_associer' => 'Asocii',
	'bouton_dissocier' => 'Malasocii',
	'bouton_fusionner' => 'Kunfandi',

	// E
	'erreur_admin_mot_action_inconnue' => 'Kion vi volas fari ?',
	'erreur_mot_cle_deja' => 'Ne eblas : estas la vorto, sur kiu vi jam estas.',
	'erreur_selection_id' => 'Elektu ŝlosilvorton aŭ indiki ĝian identigilon en la tekstokampo',

	// I
	'icone_administrer_mot' => 'Detala admin.',

	// L
	'label_associer_objets_mot' => '<b>Asocii</b> tiun vorton al la objektoj, kiuj jam havas tiun vorton',
	'label_confirm_fusion' => 'Tiu operacio ne estas nuligebla.<br />
<strong>La aktuala ŝlosilvorto #@id_mot@ estos forigita</strong> kaj la jenaj ligiloj estos alkroĉitaj al la vorto #@id_mot_new@ : ',
	'label_confirm_fusion_check' => 'Marku por konfirmi la kunfando de la vorto #@id_mot@ kun la vorto #@id_mot_new@',
	'label_dissocier_objets_mot' => '<b>Malasocii</b> tiun vorton el la objektoj, kiuj ankaŭ havas tiun vorton',
	'label_fusionner_mot' => '<b>Kunfandi</b> kun la ŝlosilvorto',
	'label_mot_1_enfant' => 'Ido :',
	'label_mot_nb_enfants' => 'Idoj :',
	'label_mot_parent' => 'Patro :',

	// P
	'placeholder_id_mot' => 'aŭ #ID_MOT',
	'placeholder_select' => 'Elekti...',

	// R
	'result_associer_nb' => 'estis asociitaj al tiu ŝlosilvorto',
	'result_associer_ras' => 'Nenio farenda : ĉiuj objektoj jam havas tiun ŝlosilvorton',
	'result_cancel_ok' => 'La lasta operacio estis nuligita.',
	'result_dissocier_nb' => 'estis malasociitaj el tiu ŝlosilvorto',
	'result_dissocier_ras' => 'Nenio farenda : neniu koncernata objekto estas asociita al tiu ŝlosilvorto',
	'result_fusionner_ok' => 'Vi povas nun forigi tiun vorton : ĉiuj ligiloj translokiĝis al la alia @mot@.',

	// T
	'titre_formulaire_administrer_mot' => 'Administri la vorton',
];
